# coding: utf-8

"""
    Arthur Scope

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from arthur_client.api_bindings.api.metrics_v1_api import MetricsV1Api


class TestMetricsV1Api(unittest.TestCase):
    """MetricsV1Api unit test stubs"""

    def setUp(self) -> None:
        self.api = MetricsV1Api()

    def tearDown(self) -> None:
        pass

    def test_get_model_metrics_versions(self) -> None:
        """Test case for get_model_metrics_versions

        Get Metric Versions
        """
        pass

    def test_post_model_metrics_by_version(self) -> None:
        """Test case for post_model_metrics_by_version

        Upload Metrics For Version
        """
        pass

    def test_post_model_metrics_query(self) -> None:
        """Test case for post_model_metrics_query

        Query Model Metrics
        """
        pass

    def test_post_model_metrics_version(self) -> None:
        """Test case for post_model_metrics_version

        Create A Metric Version
        """
        pass


if __name__ == '__main__':
    unittest.main()
